@@ -1,16 +1,11 @@
-__precompile__()
-
 module Alpine
 
 using JuMP
 
-import LinearAlgebra: dot, Diagonal
-import Statistics
 import Combinatorics
-import Pkg
+import Statistics
 
 const ALPINE_DEBUG = false
-const Alp = Alpine
 
 include("const.jl")
 
